@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
- *
- * Author:     Ji XiangLong <jixianglong@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "ccentralwidget.h"
 
 #include "clefttoolbar.h"
@@ -143,7 +127,7 @@ public:
         hLay->setSpacing(0);
 
         _leftScrollArea = new DScrollArea(_borad);
-        _leftScrollArea->setFixedWidth(68);//设置比工具栏宽10
+        _leftScrollArea->setFixedWidth(_toolManager->width());
         _leftScrollArea->setWidgetResizable(true);
         _leftScrollArea->setWidget(_toolManager);
         _leftScrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
