@@ -1,23 +1,7 @@
-/*
-* Copyright (C) 2020 ~ 2021 Deepin Technology Co., Ltd.
-*
-* Author: Zhang Hao<zhanghao@uniontech.com>
-*
-* Maintainer: WangYu <wangyu@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program. If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "dzoommenucombobox.h"
 #include "cviewmanagement.h"
 #include "cgraphicsview.h"
@@ -32,7 +16,8 @@
 #include <DPushButton>
 #include <DIconButton>
 #include <QKeyEvent>
-
+const int X_OFFSET = 14;
+const int Y_OFFSET = 9;
 DZoomMenuComboBox::DZoomMenuComboBox(DWidget *parent):
     DWidget(parent)
     , m_floatingSize(32)
@@ -279,7 +264,7 @@ void DZoomMenuComboBox::initUI()
     _btnLay->addSpacing(m_btn->width() - 2 * m_floatingSize - 2 * 5);
     _btnLay->addWidget(m_increaseBtn);
     // 设置左右按钮的位置，需要悬浮于菜单按钮的上面
-    _btnLay->setGeometry(QRect(m_btn->x() + 14, m_btn->y() + 9, m_btn->width(), m_btn->height()));
+    _btnLay->setGeometry(QRect(m_btn->x() + X_OFFSET, m_btn->y() + Y_OFFSET, m_btn->width(), m_btn->height()));
 }
 
 void DZoomMenuComboBox::initConnection()
